@@ -1,5 +1,4 @@
 from functools import wraps
-from .exceptions import PermissionError
 
 
 def require_permission(perm_func):
@@ -8,7 +7,6 @@ def require_permission(perm_func):
         def wrapper(*args, **kwargs):
             if not perm_func(*args, **kwargs):
                 # TODO : Handle errors
-                print("Not allowed")
                 return
             func(*args, **kwargs)
         return wrapper
