@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 import redis
 import pickle
 from .settings import REDIS_HOST, REDIS_PORT, REDIS_CHANNELS
@@ -12,7 +13,7 @@ def publish(channels_list=None, *args, **kwargs):
     Publishes a message on channels
     """
     channels_list = channels_list or REDIS_CHANNELS
-    p = pickle.dumps((args, kwargs))
+    p = pickle.dumps((args, kwargs), protocol=2)
 
     if not isinstance(channels_list, list):
         channels_list = [channels_list]
